TRamWAy
=======

*TRamWAy* helps analyzing single molecule dynamics.
It infers the diffusivity, drift, force and potential energy across space and time.

The `original documentation <https://tramway.readthedocs.io>`_ is now on `readthedocs <https://tramway.readthedocs.io>`_.

An attempt to rewrite the project documentation is available as a `separate project and web resource <https://tramway-tour.readthedocs.io>`_.

Installation
------------

You will need Python >= 3.6.
::

	pip install tramway

`pip install` will install some Python dependencies if missing, but you may still need to install the `HDF5 reference library <https://support.hdfgroup.org/downloads/index.html>`_.

Depending on your OS and permissions, you may also need to pass the ``--user`` option to ``pip install``.

